# coding: utf8
from __future__ import unicode_literals

import pytest

from ...vocab import Vocab
from ...tokens import Doc, Span


@pytest.mark.xfail
def test_issue1547():
    """Test that entity labels still match after merging tokens."""
    words = ['\n', 'worda', '.', '\n', 'wordb', '-', 'Biosphere', '2', '-', ' \n']
    doc = Doc(Vocab(), words=words)
    doc.ents = [Span(doc, 6, 8, label=doc.vocab.strings['PRODUCT'])]
    doc[5:7].merge()
    assert [ent.text for ent in doc.ents]



# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.ru.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "Apple рассматривает возможность покупки стартапа из Соединенного Королевства за $1 млрд",
    "Автономные автомобили переносят страховую ответственность на производителя",
    "В Сан Франциско рассматривается возможность запрета роботов-курьеров, которые перемещаются по тротуару",
    "Лондон - большой город Соединенного Королевства"
]



# coding: utf-8
from __future__ import unicode_literals

from ....attrs import HEAD, DEP
from ....symbols import nsubj, dobj, amod, nmod, conj, cc, root
from ....lang.en.syntax_iterators import SYNTAX_ITERATORS
from ...util import get_doc

import numpy


def test_en_noun_chunks_not_nested(en_tokenizer):
    text = "Peter has chronic command and control issues"
    heads = [1, 0, 4, 3, -1, -2, -5]
    deps = ['nsubj', 'ROOT', 'amod', 'nmod', 'cc', 'conj', 'dobj']

    tokens = en_tokenizer(text)
    doc = get_doc(tokens.vocab, [t.text for t in tokens], heads=heads, deps=deps)

    tokens.from_array(
        [HEAD, DEP],
        numpy.asarray([[1, nsubj], [0, root], [4, amod], [3, nmod], [-1, cc],
                       [-2, conj], [-5, dobj]], dtype='uint64'))
    tokens.noun_chunks_iterator = SYNTAX_ITERATORS['noun_chunks']
    word_occurred = {}
    for chunk in tokens.noun_chunks:
        for word in chunk:
            word_occurred.setdefault(word.text, 0)
            word_occurred[word.text] += 1
    for word, freq in word_occurred.items():
        assert freq == 1, (word, [chunk.text for chunk in tokens.noun_chunks])



# coding: utf-8
from __future__ import unicode_literals

from ..util import get_doc, get_cosine, add_vecs_to_vocab

import numpy
import pytest


@pytest.fixture
def vectors():
    return [("apple", [1, 2, 3]), ("orange", [-1, -2, -3])]


@pytest.fixture()
def vocab(en_vocab, vectors):
    add_vecs_to_vocab(en_vocab, vectors)
    return en_vocab

def test_vectors_similarity_LL(vocab, vectors):
    [(word1, vec1), (word2, vec2)] = vectors
    lex1 = vocab[word1]
    lex2 = vocab[word2]
    assert lex1.has_vector
    assert lex2.has_vector
    assert lex1.vector_norm != 0
    assert lex2.vector_norm != 0
    assert lex1.vector[0] != lex2.vector[0] and lex1.vector[1] != lex2.vector[1]
    assert numpy.isclose(lex1.similarity(lex2), get_cosine(vec1, vec2))
    assert numpy.isclose(lex2.similarity(lex2), lex1.similarity(lex1))


def test_vectors_similarity_TT(vocab, vectors):
    [(word1, vec1), (word2, vec2)] = vectors
    doc = get_doc(vocab, words=[word1, word2])
    assert doc[0].has_vector
    assert doc[1].has_vector
    assert doc[0].vector_norm != 0
    assert doc[1].vector_norm != 0
    assert doc[0].vector[0] != doc[1].vector[0] and doc[0].vector[1] != doc[1].vector[1]
    assert numpy.isclose(doc[0].similarity(doc[1]), get_cosine(vec1, vec2))
    assert numpy.isclose(doc[1].similarity(doc[0]), doc[0].similarity(doc[1]))


def test_vectors_similarity_TD(vocab, vectors):
    [(word1, vec1), (word2, vec2)] = vectors
    doc = get_doc(vocab, words=[word1, word2])
    assert doc.similarity(doc[0]) == doc[0].similarity(doc)


def test_vectors_similarity_DS(vocab, vectors):
    [(word1, vec1), (word2, vec2)] = vectors
    doc = get_doc(vocab, words=[word1, word2])
    assert doc.similarity(doc[:2]) == doc[:2].similarity(doc)


def test_vectors_similarity_TS(vocab, vectors):
    [(word1, vec1), (word2, vec2)] = vectors
    doc = get_doc(vocab, words=[word1, word2])
    assert doc[:2].similarity(doc[0]) == doc[0].similarity(doc[:2])



# coding: utf8
from __future__ import unicode_literals

import pytest

from ...language import Language
from ...vocab import Vocab


def test_issue1654():
    nlp = Language(Vocab())
    assert not nlp.pipeline
    nlp.add_pipe(lambda doc: doc, name='1')
    nlp.add_pipe(lambda doc: doc, name='2', after='1')
    nlp.add_pipe(lambda doc: doc, name='3', after='2')
    assert nlp.pipe_names == ['1', '2', '3']

    nlp2 = Language(Vocab())
    assert not nlp2.pipeline
    nlp2.add_pipe(lambda doc: doc, name='3')
    nlp2.add_pipe(lambda doc: doc, name='2', before='3')
    nlp2.add_pipe(lambda doc: doc, name='1', before='2')
    assert nlp2.pipe_names == ['1', '2', '3']



# coding: utf8
from __future__ import unicode_literals

from ...symbols import POS, PUNCT, SYM, ADJ, NUM, DET, ADV, ADP, X, VERB
from ...symbols import NOUN, PROPN, PART, INTJ, SPACE, PRON, SCONJ, AUX, CONJ


TAG_MAP = {
    "AP__Gender=Fem|Number=Plur|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Gender=Fem|Number=Sing|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Gender=Masc|Number=Plur|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Gender=Masc|Number=Sing|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Gender=Masc|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Number=Sing|Poss=Yes|PronType=Prs": {POS: DET},
    "AP__Poss=Yes|PronType=Prs": {POS: DET},
    "A__Degree=Abs|Gender=Fem|Number=Plur": {POS: ADJ},
    "A__Degree=Abs|Gender=Fem|Number=Sing": {POS: ADJ},
    "A__Degree=Abs|Gender=Masc|Number=Plur": {POS: ADJ},
    "A__Degree=Abs|Gender=Masc|Number=Sing": {POS: ADJ},
    "A__Degree=Cmp": {POS: ADJ},
    "A__Degree=Cmp|Number=Plur": {POS: ADJ},
    "A__Degree=Cmp|Number=Sing": {POS: ADJ},
    "A__Gender=Fem|Number=Plur": {POS: ADJ},
    "A__Gender=Fem|Number=Sing": {POS: ADJ},
    "A__Gender=Fem|Number=Sing|Poss=Yes|PronType=Prs": {POS: ADJ},
    "A__Gender=Masc": {POS: ADJ},
    "A__Gender=Masc|Number=Plur": {POS: ADJ},
    "A__Gender=Masc|Number=Sing": {POS: ADJ},
    "A__Number=Plur": {POS: ADJ},
    "A__Number=Sing": {POS: ADJ},
    "A___": {POS: ADJ},
    "BN__PronType=Neg": {POS: ADV},
    "B__Degree=Abs": {POS: ADV},
    "B__Degree=Abs|Gender=Masc|Number=Sing": {POS: ADV},
    "B___": {POS: ADV},
    "CC___": {POS: CONJ},
    "CS___": {POS: SCONJ},
    "DD__Gender=Fem|Number=Plur|PronType=Dem": {POS: DET},
    "DD__Gender=Fem|Number=Sing|PronType=Dem": {POS: DET},
    "DD__Gender=Masc|Number=Plur|PronType=Dem": {POS: DET},
    "DD__Gender=Masc|Number=Sing|PronType=Dem": {POS: DET},
    "DD__Gender=Masc|PronType=Dem": {POS: DET},
    "DD__Number=Plur|PronType=Dem": {POS: DET},
    "DD__Number=Sing|PronType=Dem": {POS: DET},
    "DE__PronType=Exc": {POS: DET},
    "DI__Definite=Def|Gender=Fem|Number=Plur|PronType=Art": {POS: DET},
    "DI__Gender=Fem|Number=Plur": {POS: DET},
    "DI__Gender=Fem|Number=Plur|PronType=Ind": {POS: DET},
    "DI__Gender=Fem|Number=Sing|PronType=Ind": {POS: DET},
    "DI__Gender=Masc|Number=Plur": {POS: DET},
    "DI__Gender=Masc|Number=Plur|PronType=Ind": {POS: DET},
    "DI__Gender=Masc|Number=Sing|PronType=Ind": {POS: DET},
    "DI__Number=Sing|PronType=Art": {POS: DET},
    "DI__Number=Sing|PronType=Ind": {POS: DET},
    "DI__PronType=Ind": {POS: DET},
    "DQ__Gender=Fem|Number=Plur|PronType=Int": {POS: DET},
    "DQ__Gender=Fem|Number=Sing|PronType=Int": {POS: DET},
    "DQ__Gender=Masc|Number=Plur|PronType=Int": {POS: DET},
    "DQ__Gender=Masc|Number=Sing|PronType=Int": {POS: DET},
    "DQ__Number=Plur|PronType=Int": {POS: DET},
    "DQ__Number=Sing|PronType=Int": {POS: DET},
    "DQ__PronType=Int": {POS: DET},
    "DQ___": {POS: DET},
    "DR__Number=Plur|PronType=Rel": {POS: DET},
    "DR__PronType=Rel": {POS: DET},
    "E__Gender=Masc|Number=Sing": {POS: ADP},
    "E___": {POS: ADP},
    "FB___": {POS: PUNCT},
    "FC___": {POS: PUNCT},
    "FF___": {POS: PUNCT},
    "FS___": {POS: PUNCT},
    "I__Polarity=Neg": {POS: INTJ},
    "I__Polarity=Pos": {POS: INTJ},
    "I___": {POS: INTJ},
    "NO__Gender=Fem|Number=Plur|NumType=Ord": {POS: ADJ},
    "NO__Gender=Fem|Number=Sing|NumType=Ord": {POS: ADJ},
    "NO__Gender=Masc|Number=Plur": {POS: ADJ},
    "NO__Gender=Masc|Number=Plur|NumType=Ord": {POS: ADJ},
    "NO__Gender=Masc|Number=Sing|NumType=Ord": {POS: ADJ},
    "NO__NumType=Ord": {POS: ADJ},
    "NO__Number=Sing|NumType=Ord": {POS: ADJ},
    "NO___": {POS: ADJ},
    "N__Gender=Masc|Number=Sing": {POS: NUM},
    "N__NumType=Card": {POS: NUM},
    "N__NumType=Range": {POS: NUM},
    "N___": {POS: NUM},
    "PART___": {POS: PART},
    "PC__Clitic=Yes|Definite=Def|Gender=Fem|Number=Plur|PronType=Art": {POS: PRON},
    "PC__Clitic=Yes|Gender=Fem|Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Fem|Number=Plur|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Fem|Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Fem|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Masc|Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Masc|Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Gender=Masc|Number=Sing|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Plur|Person=1|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Plur|Person=2|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Plur|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Sing|Person=1|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Sing|Person=2|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|Person=3|PronType=Prs": {POS: PRON},
    "PC__Clitic=Yes|PronType=Prs": {POS: PRON},
    "PD__Gender=Fem|Number=Plur|PronType=Dem": {POS: PRON},
    "PD__Gender=Fem|Number=Sing|PronType=Dem": {POS: PRON},
    "PD__Gender=Masc|Number=Plur|PronType=Dem": {POS: PRON},
    "PD__Gender=Masc|Number=Sing|PronType=Dem": {POS: PRON},
    "PD__Number=Plur|PronType=Dem": {POS: PRON},
    "PD__Number=Sing|PronType=Dem": {POS: PRON},
    "PD__PronType=Dem": {POS: PRON},
    "PE__Gender=Fem|Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PE__Gender=Fem|Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PE__Gender=Masc|Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PE__Gender=Masc|Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PE__Number=Plur|Person=1|PronType=Prs": {POS: PRON},
    "PE__Number=Plur|Person=2|PronType=Prs": {POS: PRON},
    "PE__Number=Plur|Person=3|PronType=Prs": {POS: PRON},
    "PE__Number=Sing|Person=1|PronType=Prs": {POS: PRON},
    "PE__Number=Sing|Person=2|PronType=Prs": {POS: PRON},
    "PE__Number=Sing|Person=3|PronType=Prs": {POS: PRON},
    "PE__Person=3|PronType=Prs": {POS: PRON},
    "PE__PronType=Prs": {POS: PRON},
    "PI__Gender=Fem|Number=Plur|PronType=Ind": {POS: PRON},
    "PI__Gender=Fem|Number=Sing|PronType=Ind": {POS: PRON},
    "PI__Gender=Masc|Number=Plur|PronType=Ind": {POS: PRON},
    "PI__Gender=Masc|Number=Sing": {POS: PRON},
    "PI__Gender=Masc|Number=Sing|PronType=Ind": {POS: PRON},
    "PI__Number=Plur|PronType=Ind": {POS: PRON},
    "PI__Number=Sing|PronType=Ind": {POS: PRON},
    "PI__PronType=Ind": {POS: PRON},
    "PP__Gender=Fem|Number=Sing|Poss=Yes|PronType=Prs": {POS: PRON},
    "PP__Gender=Masc|Number=Plur|Poss=Yes|PronType=Prs": {POS: PRON},
    "PP__Gender=Masc|Number=Sing|Poss=Yes|PronType=Prs": {POS: PRON},
    "PP__Number=Plur|Poss=Yes|PronType=Prs": {POS: PRON},
    "PP__Number=Sing|Poss=Yes|PronType=Prs": {POS: PRON},
    "PQ__Gender=Fem|Number=Plur|PronType=Int": {POS: PRON},
    "PQ__Gender=Fem|Number=Sing|PronType=Int": {POS: PRON},
    "PQ__Gender=Masc|Number=Plur|PronType=Int": {POS: PRON},
    "PQ__Gender=Masc|Number=Sing|PronType=Int": {POS: PRON},
    "PQ__Number=Plur|PronType=Int": {POS: PRON},
    "PQ__Number=Sing|PronType=Int": {POS: PRON},
    "PQ__PronType=Int": {POS: PRON},
    "PR__Gender=Masc|Number=Plur|PronType=Rel": {POS: PRON},
    "PR__Gender=Masc|Number=Sing|PronType=Rel": {POS: PRON},
    "PR__Gender=Masc|PronType=Rel": {POS: PRON},
    "PR__Number=Plur|PronType=Rel": {POS: PRON},
    "PR__Number=Sing|PronType=Rel": {POS: PRON},
    "PR__Person=3|PronType=Rel": {POS: PRON},
    "PR__PronType=Rel": {POS: PRON},
    "RD__Definite=Def": {POS: DET},
    "RD__Definite=Def|Gender=Fem": {POS: DET},
    "RD__Definite=Def|Gender=Fem|Number=Plur|PronType=Art": {POS: DET},
    "RD__Definite=Def|Gender=Fem|Number=Sing|PronType=Art": {POS: DET},
    "RD__Definite=Def|Gender=Masc|Number=Plur|PronType=Art": {POS: DET},
    "RD__Definite=Def|Gender=Masc|Number=Sing|PronType=Art": {POS: DET},
    "RD__Definite=Def|Number=Plur|PronType=Art": {POS: DET},
    "RD__Definite=Def|Number=Sing|PronType=Art": {POS: DET},
    "RD__Definite=Def|PronType=Art": {POS: DET},
    "RD__Gender=Fem|Number=Sing": {POS: DET},
    "RD__Gender=Masc|Number=Sing": {POS: DET},
    "RD__Number=Sing": {POS: DET},
    "RD__Number=Sing|PronType=Art": {POS: DET},
    "RI__Definite=Ind|Gender=Fem|Number=Plur|PronType=Art": {POS: DET},
    "RI__Definite=Ind|Gender=Fem|Number=Sing|PronType=Art": {POS: DET},
    "RI__Definite=Ind|Gender=Masc|Number=Plur|PronType=Art": {POS: DET},
    "RI__Definite=Ind|Gender=Masc|Number=Sing|PronType=Art": {POS: DET},
    "RI__Definite=Ind|Number=Sing|PronType=Art": {POS: DET},
    "RI__Definite=Ind|PronType=Art": {POS: DET},
    "SP__Gender=Fem|Number=Plur": {POS: PROPN},
    "SP__NumType=Card": {POS: PROPN},
    "SP___": {POS: PROPN},
    "SW__Foreign=Yes": {POS: X},
    "SW__Foreign=Yes|Gender=Masc": {POS: X},
    "SW__Foreign=Yes|Number=Sing": {POS: X},
    "SYM___": {POS: SYM},
    "S__Gender=Fem": {POS: NOUN},
    "S__Gender=Fem|Number=Plur": {POS: NOUN},
    "S__Gender=Fem|Number=Sing": {POS: NOUN},
    "S__Gender=Masc": {POS: NOUN},
    "S__Gender=Masc|Number=Plur": {POS: NOUN},
    "S__Gender=Masc|Number=Sing": {POS: NOUN},
    "S__Gender=Masc|Number=Sing|Tense=Past|VerbForm=Part": {POS: NOUN},
    "S__Number=Plur": {POS: NOUN},
    "S__Number=Sing": {POS: NOUN},
    "S___": {POS: NOUN},
    "Sw___": {POS: X},
    "T__Gender=Fem|Number=Plur|PronType=Tot": {POS: DET},
    "T__Gender=Fem|Number=Sing": {POS: DET},
    "T__Gender=Fem|Number=Sing|PronType=Tot": {POS: DET},
    "T__Gender=Masc|Number=Plur|PronType=Tot": {POS: DET},
    "T__Gender=Masc|Number=Sing|PronType=Tot": {POS: DET},
    "T__Number=Plur|PronType=Tot": {POS: DET},
    "T__PronType=Tot": {POS: DET},
    "VA__Gender=Fem|Number=Plur|Tense=Past|VerbForm=Part": {POS: AUX},
    "VA__Gender=Fem|Number=Sing|Tense=Past|VerbForm=Part": {POS: AUX},
    "VA__Gender=Masc|Number=Plur|Tense=Past|VerbForm=Part": {POS: AUX},
    "VA__Gender=Masc|Number=Sing|Tense=Past|VerbForm=Part": {POS: AUX},
    "VA__Mood=Cnd|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Cnd|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Cnd|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Cnd|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=1|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=2|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=2|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=3|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=3|Tense=Past|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=1|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=1|Tense=Past|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=2|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=3|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=3|Tense=Past|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Ind|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Sing|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VA__Mood=Sub|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VA__VerbForm=Ger": {POS: AUX},
    "VA__VerbForm=Inf": {POS: AUX},
    "VM__Gender=Fem|Number=Sing|Tense=Past|VerbForm=Part": {POS: AUX},
    "VM__Gender=Masc|Number=Sing|Tense=Past|VerbForm=Part": {POS: AUX},
    "VM__Mood=Cnd|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Cnd|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Cnd|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Cnd|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Cnd|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Cnd|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Imp|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Imp|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=1|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=2|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=3|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=3|Tense=Past|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=2|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=2|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=3|Tense=Fut|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=3|Tense=Past|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Ind|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Plur|Person=1|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: AUX},
    "VM__Mood=Sub|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: AUX},
    "VM__VerbForm=Ger": {POS: AUX},
    "VM__VerbForm=Inf": {POS: AUX},
    "V__Gender=Fem|Number=Plur|Tense=Past|VerbForm=Part": {POS: VERB},
    "V__Gender=Fem|Number=Sing|Tense=Past|VerbForm=Part": {POS: VERB},
    "V__Gender=Masc|Number=Plur|Tense=Past|VerbForm=Fin": {POS: VERB},
    "V__Gender=Masc|Number=Plur|Tense=Past|VerbForm=Part": {POS: VERB},
    "V__Gender=Masc|Number=Sing|Tense=Past|VerbForm=Part": {POS: VERB},
    "V__Mood=Cnd|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Cnd|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Cnd|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Cnd|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Cnd|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Cnd|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Imp|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Imp|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Imp|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Imp|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=1|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=1|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=1|Tense=Past|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=2|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=3|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=3|Tense=Past|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=1|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=1|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=1|Tense=Past|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=2|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=3|Tense=Fut|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=3|Tense=Past|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Ind|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=1|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=2|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=3|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=1|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=1|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=2|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=3|Tense=Imp|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=3|Tense=Pres|VerbForm=Fin": {POS: VERB},
    "V__Mood=Sub|Number=Sing|Person=3|VerbForm=Fin": {POS: VERB},
    "V__Number=Plur|Tense=Pres|VerbForm=Part": {POS: VERB},
    "V__Number=Sing|Tense=Pres|VerbForm=Part": {POS: VERB},
    "V__Tense=Past|VerbForm=Part": {POS: VERB},
    "V__VerbForm=Ger": {POS: VERB},
    "V__VerbForm=Inf": {POS: VERB},
    "X___": {POS: X},
    "_SP": {POS: SPACE}
}



# coding: utf8
from __future__ import unicode_literals

from ...symbols import POS, PUNCT, ADJ, CONJ, SCONJ, NUM, DET, ADV, ADP, X, VERB
from ...symbols import NOUN, PROPN, PART, INTJ, SPACE, PRON, AUX


TAG_MAP = {
    "$(":       {POS: PUNCT, "PunctType": "brck"},
    "$,":       {POS: PUNCT, "PunctType": "comm"},
    "$.":       {POS: PUNCT, "PunctType": "peri"},
    "ADJA":     {POS: ADJ},
    "ADJD":     {POS: ADJ, "Variant": "short"},
    "ADV":      {POS: ADV},
    "APPO":     {POS: ADP, "AdpType": "post"},
    "APPR":     {POS: ADP, "AdpType": "prep"},
    "APPRART":  {POS: ADP, "AdpType": "prep", "PronType": "art"},
    "APZR":     {POS: ADP, "AdpType": "circ"},
    "ART":      {POS: DET, "PronType": "art"},
    "CARD":     {POS: NUM, "NumType": "card"},
    "FM":       {POS: X, "Foreign": "yes"},
    "ITJ":      {POS: INTJ},
    "KOKOM":    {POS: CONJ, "ConjType": "comp"},
    "KON":      {POS: CONJ},
    "KOUI":     {POS: SCONJ},
    "KOUS":     {POS: SCONJ},
    "NE":       {POS: PROPN},
    "NNE":      {POS: PROPN},
    "NN":       {POS: NOUN},
    "PAV":      {POS: ADV, "PronType": "dem"},
    "PROAV":    {POS: ADV, "PronType": "dem"},
    "PDAT":     {POS: DET, "PronType": "dem"},
    "PDS":      {POS: PRON, "PronType": "dem"},
    "PIAT":     {POS: DET, "PronType": "ind|neg|tot"},
    "PIDAT":    {POS: DET, "AdjType": "pdt", "PronType": "ind|neg|tot"},
    "PIS":      {POS: PRON, "PronType": "ind|neg|tot"},
    "PPER":     {POS: PRON, "PronType": "prs"},
    "PPOSAT":   {POS: DET, "Poss": "yes", "PronType": "prs"},
    "PPOSS":    {POS: PRON, "Poss": "yes", "PronType": "prs"},
    "PRELAT":   {POS: DET, "PronType": "rel"},
    "PRELS":    {POS: PRON, "PronType": "rel"},
    "PRF":      {POS: PRON, "PronType": "prs", "Reflex": "yes"},
    "PTKA":     {POS: PART},
    "PTKANT":   {POS: PART, "PartType": "res"},
    "PTKNEG":   {POS: PART, "Polarity": "Neg"},
    "PTKVZ":    {POS: PART, "PartType": "vbp"},
    "PTKZU":    {POS: PART, "PartType": "inf"},
    "PWAT":     {POS: DET, "PronType": "int"},
    "PWAV":     {POS: ADV, "PronType": "int"},
    "PWS":      {POS: PRON, "PronType": "int"},
    "TRUNC":    {POS: X, "Hyph": "yes"},
    "VAFIN":    {POS: AUX, "Mood": "ind", "VerbForm": "fin"},
    "VAIMP":    {POS: AUX, "Mood": "imp", "VerbForm": "fin"},
    "VAINF":    {POS: AUX, "VerbForm": "inf"},
    "VAPP":     {POS: AUX, "Aspect": "perf", "VerbForm": "part"},
    "VMFIN":    {POS: VERB, "Mood": "ind", "VerbForm": "fin", "VerbType": "mod"},
    "VMINF":    {POS: VERB, "VerbForm": "inf", "VerbType": "mod"},
    "VMPP":     {POS: VERB, "Aspect": "perf", "VerbForm": "part", "VerbType": "mod"},
    "VVFIN":    {POS: VERB, "Mood": "ind", "VerbForm": "fin"},
    "VVIMP":    {POS: VERB, "Mood": "imp", "VerbForm": "fin"},
    "VVINF":    {POS: VERB, "VerbForm": "inf"},
    "VVIZU":    {POS: VERB, "VerbForm": "inf"},
    "VVPP":     {POS: VERB, "Aspect": "perf", "VerbForm": "part"},
    "XY":       {POS: X},
    "_SP":      {POS: SPACE}
}



# coding: utf8

from __future__ import unicode_literals
from ...language import Language


def test_simple_ner():
    cfg = {
        'hidden_depth': 2,  # should error out
    }

    nlp = Language()
    nlp.add_pipe(nlp.create_pipe('ner'))
    nlp.get_pipe('ner').add_label('answer')
    try:
        nlp.begin_training(**cfg)
        assert False  # should error out
    except ValueError:
        assert True
